function [blog, lpsd] = check_rings(a, b_c2, b_f, prepro, sigmas, spa_sig, tonal_sig ,perav_sem, patchSz, iterNo)
% CHECK RINGS By changing the binning and filter's parameters rings could
% be made more pronounced. This function helps in finding the optimal
% choice 
% SYNOPSIS:
%  blog = check_rings(a, b_c2, b_f, prepro, sigmas, spa_sig, tonal_sig ,perav_sem, patchSz, iterNo)
%
% INPUT:
%         a:   input image (preferably of (near-) amourphous sample)
%      b_c2:   binning in real space
%       b_f:   binning in Fourier domain
%    prepro:   filtering method specified by string 'adaptive'[1-5], 'bilateral'[1-10] , 
%             'laplace', 'adaptivespecify' or 'bilateralspecify'
% for 'adaptivespecify' or 'bilateralspecify' specify
%    sigmas:   Array containing the sigmas of the derivatives.e.g. [1 1]  
% if 'bilateralspecify' specify 
%   spa_sig:   sigma of the Gaussian spatial weight (used for bilateral only e.g. 2)
% tonal_sig:   sigma of the Gaussian tonal weight (used for bilateral only e.g. 20) 
% perav_sem:   periodogram averaging (yes=1, no=0) Default =0;
%   patchSz:   patch size (default: half of the image size)
%    iterNo:   number of patches used (default=20);
%
% OUTPUT:
%  blog: background-suppressed and contrast inverted PSD   


% (C) Copyright 2011
%  Quantitative Imaging Group      Leiden University Medical Center
%  Faculty of Applied Sciences     Department of Molecular Cell Biology
%  Delft University of Technology  Section Electron Microscopy
%  Lorentzweg 1                    2300 RC Leiden
%  2628 CJ Delft
%  The Netherlands
%
% Milos Vulovic

%% -------------------------processing of the PSD
minsz = min(size(squeeze(a)));
if nargin<10 
    iterNo = 20;end
if nargin<10 
patchSz = (minsz/b_c2)/2;end % patch size for periodogram averaging
if ~exist('perav_sem');perav_sem = 0;end  % perodogram averaging (yes=1, no=0);
if ~exist('spa_sig');spa_sig = [ ];end  % perodogram averaging (yes=1, no=0);
if ~exist('tonal_sig');tonal_sig = [];end  % perodogram averaging (yes=1, no=0);
a = cut(a,minsz); % make the sqaured image  (it will be extended to rectangular case later)
% in order to allow the binning upto in total 16, it is desirable that image
% dimentions are divisable by 16
a = squeeze(cut(a,minsz - mod(minsz,16)));
imsize = size(a,1);%the size of the image
%a = a*hannwind(imsize); % apply the hann window to suppress edge effects
%spatial rebinning
if b_c2 > 1 %rebin the image in the spatial domain first
    a = rebin(a,b_c2)/b_c2^2;
end
szpera = size(a,1);
%rebining due to the periodogram averaging
fdrebin = 1;
if perav_sem
    [psd, fdrebin] = per_av(a, patchSz, iterNo);
else
    in = squeeze((a) - mean(a));
    clear a
    psd = abs(ft(in)).^2;
end
%additional rebinning in the Fourier domain
if b_f > 1
    psd = rebin(psd,b_f)/b_f^2;
end

lpsd = log(psd);

blog = prefilt(lpsd, prepro, sigmas, spa_sig, tonal_sig); %preprocess the PSD % prefered filters bilateral and adaptive. 
% blog1=newim(lpsd);
% blog1(0:size(lpsd,1)/2-1, :)=lpsd(0:size(lpsd,1)/2-1, :)/max(lpsd(0:size(lpsd,1)/2-1, :));
% blog1(size(lpsd,1)/2: size(lpsd,1)-1, :)= blog(size(lpsd,1)/2: size(lpsd,1)-1, :)/max(blog(size(lpsd,1)/2: size(lpsd,1)-1, :));
dipshow(blog, 'lin')

