function impol = dek2pol(inimage, method)
% DEK2POL transforms image from Cartesian to polar represenation 
% SYNOPSIS:
%  impol = dek2pol(inimage, method)
%
% INPUT:
% inimage: input image
%  method: interpolation method -'linear', 'spline', 'cubic', 'nearest'
%
% OUTPUT:
%  impol: image in polar representation
%
% DEFAULTS:
%  method: 'cubic'

% (C) Copyright 2011
%  Quantitative Imaging Group      Leiden University Medical Center
%  Faculty of Applied Sciences     Department of Molecular Cell Biology
%  Delft University of Technology  Section Electron Microscopy
%  Lorentzweg 1                    2300 RC Leiden
%  2628 CJ Delft
%  The Netherlands
%
%  Milos Vulovic

if nargin<2
    method = 'cubic';
end
%scaling for equidistant
% p=1 normal , p=0.5 equidistant sampling
sc = 1;
p = 1;
N = size(inimage,2);
sz = [N N];
radstep = 1;
rad = 0:radstep:floor(min(sz)/2)-1; 
Nrad = size(rad,2);%half of the size of the binned image (radius range)
phistep = 0.01;
phi = 0:phistep:(floor(pi/phistep)-1)*pi/floor(pi/phistep);
Nphi = size(phi,2);
rad2 = sc*dip_image(repmat(rad',1,Nphi).^p);
phi2 = dip_image(repmat(phi,Nrad,1));
[x,y] = pol2cart(phi2,rad2);
x = reshape(x + floor(sz(1)/2), 1, Nrad*Nphi);
y = reshape(y + floor(sz(2)/2), 1, Nrad*Nphi);
impol0 = get_subpixel(inimage, double([x, y]), method );
impol = dip_image(reshape(impol0, Nphi, Nrad));