%  --This is an example that demonstrates the defocus and astigmatism estimation 
%    for underfocus (df>0, A1>0), without Cs correction, moderate magnification 
%    and relatively small astigmatism. 

%% ----input parameters for defocus and astigmatism estimation
%  They must be provided as input for the function estimate_df_ast.m
%  The parameters are described in a structure file params and they are 
%  organized in 2 groups. The first group consists of the parameters that 
%  must be provided (obligatory!) and they describe imaging conditions. 
%  In this example a test unbinned image is acquired at a magnification of 
%  62k on a microscope operated at 200kV voltage and equipped with 4k camera. 
%  Spherical aberration of objective lens is 2mm. 
%  The 2nd group includes the processing parameters (optional). Their default 
%  values are specified within estimate_df_ast.m. Check out examples2-4 and example_check_rings to 
%  see how to change default values to better suit your acquisition (see 
%  also section 3 in def_ast_estimator_manual.pdf for some recommendations)
%  NOTE that the convention for defocus sign in this program is opposite from the one used in most microscopes 
clear all
close all
% ------reading the image
imagename='Image4example1.tif';
a = readim(imagename);

%% -----obligatory input (acquisition conditions)
% --1a) pixel size
% you can either specify the (post)magnification and physical pixel size or
% directly specify the pixel size in the specimen plane:

% 1a1)mag and postmag and physical pixel size
magmic          = 62000; %                      <--specify magnification
CLfac           = 1.31; %           <--specify post-magnification factor
%                                    between plane of the film plate and your camera
ph_pixsize      = 15e-6; %                       <--specify CCD physical pixel size
params.bin      = 1; %                           <-- specify binning of acquired images
params.pixsize  = ph_pixsize*params.bin/(magmic*CLfac);
% 1a2) or specify pixel size in the image plane directly
params.pixsize  = params.pixsize; %              <--or specify pixel size directly!

% --1b) microscope parameters
params.voltage  = 200e3;%                      <--specify voltage
params.Cs       = 2e-3;%                       <--specify spherical aberration

%% ----ESTIMATE DEFOCUS AND ASTIGMATISM AND CORRESPONING UNCERTINTIES!
[df, std_df, ellipticity, angle, ast, std_ast] = estimate_df_ast(a,params);


