%%%  --These are 2 examples with function check_rings.m which could be used as 
% a help to make Thon rings more prominent (semi-automatic approach).
% It can facilitate the best choise of rebinning and filtering parameters of the PSD.
% For more details see def_ast_estimator_manual.pdf

% -NOTE1: binning
% For the PSD that has wider rings which also extend to high fraction of Nyquist frequency
% (e.g. relatively lower magnification and lower defocus), binning in the Fourier domain (ExampleB below) might be beneficial. 
% If the PSD has rings that are narrow and close to each other, but they do not extend to a high fraction of Nyquist frequency
% (e.g. relatively high magnification and high defocus), spatial binning (ExampleA below) is beneficial.
% -NOTE2: filtering
% If you have difficulties finding the rings due to poor SNR, bilteral filtering might be beneficial (bilateralspec)

clear all
close all
%% ExampleA : 'adaptivespec' type of filtering

% ------reading the image
imagename = 'Image4example3';
a = readim(imagename);
prepro       = 'adaptivespec'; %preprocessing options : 'adaptive', 'bilateral', 'adaptivespec', 'bilateralspec'. 
b_c2         = 4;      % real space binning (options: 1,2,4,8).
b_f          = 2;      % binning in Fourier domain (options:1,2,4,8)
sigmas       = [3 1];  % sigmas of filter derivatives (used for 'adaptivespec' and 'bilateralspec')
                       % the filter smooths more along the Thon rings than perpendicular to it (anisotropic)
% spa_sig      = 1;    % spatial sigma for 'bilaterspec' filter
% tonal_sig    = 20;   % tonal sigma for 'bilaterspec' filter                                                  
% perav_sem    = 1;    % perodogram averaging (yes=1, no=0); Default: 0.
% iterNo       = 20;   % number of patches for periodogram averaging
% patchSz      = 512;  % Patch size for periodogram averaging 

[blog1, lpsd1] = check_rings(a, b_c2, b_f, prepro, sigmas);
% OUTPUT: 
% blog1 : filtered PSD (contrast is inverted and background removed)
% lpsd1 : PSD after rebinning in spatial and frequency domain

%% ExampleB : 'bilateralspec' type of filtering

% ------reading the image
imagename = 'Image4example4';
a = readim(imagename);
prepro       = 'bilateralspec'; %preprocessing options : 'adaptive','bilateral', 'adaptivespec', 'bilateralspec'.
b_c2         = 1;     % real space binning (options: 1,2,4,8).
b_f          = 8;     % binning in Fourier domain (options:1,2,4,8)
sigmas       = [2];   % sigmas of filter derivatives (used for 'adaptivespec' and 'bilateralspec'). 
                      % Anisotropic in case of 'adaptivespec'
spa_sig      = 2;     % spatial sigma for 'bilaterspec' filter
tonal_sig    = 20;    % tonal sigma for 'bilaterspec' filter                                                  
% perav_sem    = 1;   % perodogram averaging (yes=1, no=0); Default: 0.
% iterNo       = 20;  % number of patches for periodogram averaging
% patchSz      = 512; % Patch size for periodogram averaging 

[blog2, lpsd2] = check_rings(a, b_c2, b_f, prepro, sigmas, spa_sig, tonal_sig );
% OUTPUT: 
% blog2 : filtered PSD (contrast is inverted and background removed)
% lpsd2 : PSD after rebinning in spatial and frequency domain

%[blog, lpsd] = check_rings(a, b_c2, b_f, prepro, sigmas, spa_sig, tonal_sig ,perav_sem, patchSz, iterNo)


