function E = gauss1D(x, x0, FWHM, order)
%GAUSS: Creates a gaussian function.
%
%   E = gauss(x, FWHM, order)
%     = exp(-log(2)*(2*(x-x0)./FWHM).^(2*floor(abs(order))));
%
%	x		= Domain
%	x0		= Centre position
%	FWHM	= Full width half max
%	order	= Gaussian order
%
%	v1.0
%Computes the Gaussian function in 1D:
% exp(-log(2)*(2*(x-x0)./FWHM).^(2*floor(abs(order))));
% 
% Where:
% x = Co-ordinate
% x0 = Centre of function
% FWHM = Full Width Half Max of the function
% order = Gaussian order
% 
% Normal Gaussian is of order 1.
% 
% Note that FWHM = (1/e Half Width)/sqrt(2*log(2))
% log is the natural log.

E = exp(-log(2)*(2*(x-x0)./FWHM).^(2*floor(abs(order))));