function out = gen_templates(A1, N, wrsem)
% GEN_TEMPLATES generates conjugated Fourier transforms of the templates 
%
% SYNOPSIS:
%   out = gen_templates(A1, N, wrsem)
%
% INPUT:
%   A1: range of the template ellipticities (must be vector containing
%       values A0:step:Amax)
%    N: size of the PSD to match to. Template size in x axis direction is 
%       therefore N/2. The vertiacal axis represents the angles from 0:0.01:pi
%wrsem: =1 if tempate is to be written, =0 otherwise
%
% OUTPUT:
%  out: stack of conjugated Fourier transform of the templates
%
% DEFAULTS:
% wrsem = 0

% (C) Copyright 2011
%  Quantitative Imaging Group      Leiden University Medical Center
%  Faculty of Applied Sciences     Department of Molecular Cell Biology
%  Delft University of Technology  Section Electron Microscopy
%  Lorentzweg 1                    2300 RC Leiden
%  2628 CJ Delft
%  The Netherlands
%
%  Milos Vulovic & Bernd Rieger

if nargin < 3
    wrsem = 0;
end
template_settings
dR = A1(2)-A1(1);
mR = A1(end);
fprintf('file name %s\n', ['img_' num2str(N) '_dR' num2str(dR) '_Rmax' num2str(mR) '.ics'])
radius_c = N/4;
xa = xx(N,N);
ya = yy(N,N);
xdot = dip_image(xa*cos(0) - ya*sin(0),'dfloat');
ydot = dip_image(xa*sin(0) + ya*cos(0),'dfloat'); %template has 0 angle
ydot2 = ydot.^2;
sigma = 1;
jj = 0;
phistep = 0.01;
phi = 0:phistep:(floor(pi/phistep)-1)*pi/floor(pi/phistep);
Nphi = size(phi,2);
Nrad = N/2;
out = newim([Nrad Nphi length(A1)],'scomplex');
%templates=out;
for ii = A1
    fprintf('template ratio %2.4f\n',ii);   
    q = sqrt((xdot/ii ).^2+ydot2);%
    radius_short = sqrt(radius_c^2*(ii^2+1)/(2*ii^2));%+ sigma^2);
    tmp = dip_image(gaussianlineclip(q-radius_short, sigma),'sfloat');%template has the center in the center of the image
    tmp = tmp./sum(tmp);
    disk = dek2pol(tmp, 'cubic');
%     templates(:,:,jj) = disk;
    ftdisk = conj(ft(disk));
    out(:,:,jj) = ftdisk;
    jj = jj+1;
end
if wrsem == 1
    writeim(out,[templateDIR 'img_' num2str(N) '_dR' num2str(dR) 'Rmax' num2str(mR) '.ics'],'ics',0)
end
