function [sortall, missedzeros] = reject_out(sortall,sz,disexpect_mic)
% REJECT_OUT detects the spurious and missing rings (based on equdistance
%            of the CTF zeros in q2 space
%
% SYNOPSIS:
%   [sortall, missedzeros] = reject_out(sortall, sz, disexpect_mic)
%
% INPUT:
%       sortall: array of the detected CTF zero positions
%            sz: size of the input PSD 
% disexpect_mic: if it exists, the equdistance in pixels will be used from 
%                the defocus value from the microscope
%
% OUTPUT:
%     sortall: the array of the postion of the rings that belong to the
%              prediction pattern
% missedzeros: CTF zeros that are missed in detection



% (C) Copyright 2011
%  Quantitative Imaging Group      Leiden University Medical Center
%  Faculty of Applied Sciences     Department of Molecular Cell Biology
%  Delft University of Technology  Section Electron Microscopy
%  Lorentzweg 1                    2300 RC Leiden
%  2628 CJ Delft
%  The Netherlands
%
% Milos Vulovic

    zeros_eq = (sortall(:,1)).^2/(min(sz)/2);
    %zeropos= sortall(:,1);

        for jj=1:length(zeros_eq)-1
                equidist(jj)= zeros_eq(jj+1)- zeros_eq(jj); % checking the neigbours
        end
        disexpect=abs(median(equidist(1:end))); 
        missedzeros=[]; 
        if nargin==3
            disexpect=disexpect_mic;
        end        
try
   [cout,preskok]= check_outliers2(zeros_eq,disexpect);
   excluded=length(sortall)-length(cout);
   sortall(end-excluded+1:end)=[];
   sortall=sqrt(cout*(min(sz)/2));
   [xraw,ycol,zval]=find(preskok);
   cszval=cumsum(zval);
    for lll=0:length(zval)-1
        missedzeros= [ missedzeros ycol(lll+1)+cszval(lll+1)-zval(lll+1): ycol(lll+1)+cszval(lll+1)-1] ;
    end
catch
    fprintf('Could not perform outlier rejection\n');   
    return
end
